@@ -18,10 +18,10 @@ ADOBEFONTS_PROFILE_CHECKS = \
     ]
 
 OVERRIDDEN_CHECKS = [
-        'com.google.fonts/check/dsig',
-        'com.google.fonts/check/whitespace_glyphs',
-        'com.google.fonts/check/valid_glyphnames',
-        ]
+    'com.google.fonts/check/dsig',
+    'com.google.fonts/check/whitespace_glyphs',
+    'com.google.fonts/check/valid_glyphnames',
+]
 ADOBEFONTS_PROFILE_CHECKS += [f'{cid}:{profile.profile_tag}' for cid in OVERRIDDEN_CHECKS]
 
 ADOBEFONTS_PROFILE_CHECKS[:] = [cid for cid in ADOBEFONTS_PROFILE_CHECKS
@@ -29,10 +29,10 @@ ADOBEFONTS_PROFILE_CHECKS[:] = [cid for cid in ADOBEFONTS_PROFILE_CHECKS
 
 
 @check(
-  id = 'com.adobe.fonts/check/family/consistent_upm',
-  rationale = """
-    While not required by the OpenType spec, we (Adobe) expect that a group of fonts designed & produced as a family have consistent units per em.
-  """
+    id = 'com.adobe.fonts/check/family/consistent_upm',
+    rationale = """
+        While not required by the OpenType spec, we (Adobe) expect that a group of fonts designed & produced as a family have consistent units per em.
+    """
 )
 def com_adobe_fonts_check_family_consistent_upm(ttFonts):
     """Fonts have consistent Units Per Em?"""
@@ -40,8 +40,7 @@ def com_adobe_fonts_check_family_consistent_upm(ttFonts):
     for ttFont in ttFonts:
         upm_set.add(ttFont['head'].unitsPerEm)
     if len(upm_set) > 1:
-        yield FAIL, ("Fonts have different units per em: {}."
-                     ).format(sorted(upm_set))
+        yield FAIL, f"Fonts have different units per em: {sorted(upm_set)}."
     else:
         yield PASS, "Fonts have consistent units per em."
 
@@ -74,12 +73,12 @@ def _quick_and_dirty_glyph_is_empty(font, glyph_name):
 
 
 @check(
-  id = 'com.adobe.fonts/check/find_empty_letters',
-  rationale = """
-    Font language, script, and character set tagging approaches typically have an underlying assumption that letters (i.e. characters with Unicode general category 'Ll', 'Lm', 'Lo', 'Lt', or 'Lu', which includes CJK ideographs and Hangul syllables) with entries in the 'cmap' table have glyphs with ink (with a few exceptions, notably the Hangul "filler" characters).
+    id = 'com.adobe.fonts/check/find_empty_letters',
+    rationale = """
+        Font language, script, and character set tagging approaches typically have an underlying assumption that letters (i.e. characters with Unicode general category 'Ll', 'Lm', 'Lo', 'Lt', or 'Lu', which includes CJK ideographs and Hangul syllables) with entries in the 'cmap' table have glyphs with ink (with a few exceptions, notably the Hangul "filler" characters).
 
-    This check is intended to identify fonts in which such letters have been mapped to empty glyphs (typically done as a form of subsetting). Letters with empty glyphs should have their entries removed from the 'cmap' table, even if the empty glyphs are left in place (e.g. for CID consistency).
-  """
+        This check is intended to identify fonts in which such letters have been mapped to empty glyphs (typically done as a form of subsetting). Letters with empty glyphs should have their entries removed from the 'cmap' table, even if the empty glyphs are left in place (e.g. for CID consistency).
+    """
 )
 def com_adobe_fonts_check_find_empty_letters(ttFont):
     """Letters in font have glyphs that are not empty?"""
@@ -122,9 +121,11 @@ com_google_fonts_check_dsig_adobefonts = profile.check_log_override(
     ,)
 )
 
-com_google_fonts_check_whitespace_glyphs_adobefonts = profile.check_log_override(
-    'com.google.fonts/check/whitespace_glyphs'
-  , overrides = (('missing-whitespace-glyphs', WARN, None),)
+com_google_fonts_check_whitespace_glyph_nbsp = profile.check_log_override(
+    'com.google.fonts/check/whitespace_glyphs',
+    reason='For Adobe, this is not as severe '\
+           + 'as assessed in the original check for 0x00A0.',
+    overrides = (('missing-whitespace-glyph-0x00A0', WARN, None),)
 )
 
 com_google_fonts_check_valid_glyphnames_adobefonts = profile.check_log_override(
